# intl-extract

该脚本配合[react-intl-universal](https://npm.alibaba-inc.com/package/react-intl-universal)以及[美杜莎平台](https://mcms-portal.alibaba-inc.com/v3/applicationList)进行国际化相关的操作，支持以下能力：
- `扫描本地文案并同步美杜莎`
- `扫描本地文案输出到本地文件`
- `调用机器翻译`
- `发布美杜莎文案`
- `下载美杜莎文案到本地`
- `本地中文硬编码检测`

### 使用流程
请参考[文档](https://yuque.antfin-inc.com/santa-doc/bk0aig/hcacf1)建立美杜莎应用，以及授权公用帐号one_box。

### Install
```
tnpm ii --save-dev @ali/onebox-intl-extract
```

### Usage
在项目package.json
```
"scripts": {
  "intl:sync": "onebox-intl-extract --cmd sync --app-name 美杜莎应用名",
  "intl:export": "onebox-intl-extract --cmd export --app-name 美杜莎应用名 -r",
  "intl:detect": "onebox-intl-extract --cmd detect",
  "intl:translate": "onebox-intl-extract --cmd translate --app-name 美杜莎应用名",
  "intl:audit": "onebox-intl-extract --cmd audit --app-name 美杜莎应用名",
  "intl": "npm run intl:export && npm run intl:sync && npm run intl:translate && npm run intl:audit && npm run intl:export"
  "intl:scan": "onebox-intl-extract --cmd scan"
},
"devDependencies": {
  "@ali/onebox-intl-extract": "*",
}
```

- `intl:sync`: 同步本地代码中文案到美杜莎
- `intl:scan`: 抽取本地代码文案到本地语言包
- `intl:export`: 下载美杜莎语言包到本地
- `intl:detect`: 检测代码中文硬编码
- `intl:translate`: 调用机器翻译美杜莎文案
- `intl:audit`: 发布待发布文案
- `intl`: 依次执行下载、同步、翻译、发布和下载命令，实现一键处理国际化文案，


### 参数定义

#### 通用参数

| 名称（简写）      | 是否必填               | 默认值                        | 描述                                                           |
|-------------------|------------------------|-------------------------------|----------------------------------------------------------------|
| -c, --cmd         | 是                     | 无                            | 调用的命令，仅支持以上六种，必填                               |
| --app-name        | 除detect、scan命令必填 | 无                            | 美杜莎平台申请的应用名称                                       |
| --path            | 否                     | './'                          | 命令默认路径，用于扫描、导出、同步等起始文件位置               |
| --bucId           | 否                     | onebox公用账号                | 用于美杜莎系统鉴权                                             |
| --extensions      | 否                     | '[".js",".jsx",".ts",".tsx"]' | 支持的文件类型                                                 |
| --default-locale  | 否                     | 'zh_CN'                       | 默认语言                                                       |
| --support-locales | 否                     | "['zh_CN', 'en_US', 'zh_TW']" | 支持的语言列表，如果支持的语言不同于默认值，则需要传递这个参数 |
| --ignore          | 否                     |                               | 需要忽略的文件，支持glob模式                                   |

#### 命令支持参数
> detect

| 名称（简写）    | 是否必填 | 默认值                                   | 描述                             |
|-----------------|----------|------------------------------------------|----------------------------------|
| --ignore-regexp | 否       | 检测注释和react-intl-universal格式的正则 | 执行检测中文命令时需要忽略的正则 |

> scan

| 名称（简写）  | 是否必填 | 默认值     | 描述                         |
|---------------|----------|------------|------------------------------|
| --export-path | 否       | './medusa' | 扫描本地文案输出到本地的路径 |

> export

| 名称（简写）         | 是否必填 | 默认值          | 描述                                                                      |
|----------------------|----------|-----------------|---------------------------------------------------------------------------|
| --output             | 否       | './src/locales' | 下载文案到本地的路径                                                      |
| -r,--replace-default | 否       | fasle           | 下载美杜莎文案到本地时如果文案发生变化是否替换代码中的默认文案（.d(XXX)） |


### 几点注意
1. 脚本皆为批量操作，对于同步、翻译和发布等指令一定要慎重使用
2. 建议下载文案时，开启替换默认值的开关。这样从美杜莎下载文案会自动替换本地默认值
3. 建议执行同步文案命令时，先执行下载命令拉取最新文案，避免互相覆盖
4. 建议文案修改统一在美杜莎平台进行修改，然后执行下载命令
5. 各命令都可分开执行，不建议直接`tnpm run intl`，有时候会有问题

### Doc
具体请参考文档：https://lark.alipay.com/santa-doc/bk0aig/hcacf1


### Development
- test: `tnpm run test`

