/**
 * 扫描本地代码中的文案，然后输出到文件
 */

const fs = require('fs');
const pathTool = require('path');
const chalk = require('chalk');
const _ = require('lodash');
const ignore = require('ignore');
const { processParameters, scanFiles, verifyMessages } = require('../util/util');
const cwd = process.cwd();

let ig;

/**
 * 扫描本地代码中的国际化文案，并写到文件
 * @param {{ bucId, appName, path, targetExtensions,  excludeDirName }} options
 */
const scan = (options = {}) => {
  const params = processParameters('scan', options);
  ig = ignore().add(_.get(params, 'ignore', []));
  const startPath = pathTool.join(cwd, params.path);
  console.log(chalk.magenta(`================== 开始扫描文案 ==================`));
  let messages = scanFiles(startPath, params, ig);
  messages = _.sortBy(messages, 'key');
  if (verifyMessages(messages)) {
    const exportPath = pathTool.join(cwd, _.get(params, 'exportPath', './'));
    try {
      writeFile(messages, exportPath);
    }
    catch (e) {
      console.log(chalk.red('write file error', e));
    }
  } else {
    console.error(chalk.red('侦测到部分文案没默认值，或者默认值不一致，请先解决以上问题，才能与美杜沙同步'))
  }
  return messages;
};

/**
 * 写文件
 * @param {{key: string, sourceDefaultMessage: string, targetDefaultMessage: string}[]} messages 
 * @param {string} filePath 
 */
function writeFile(messages, filePath) {
  const sourceObj = {};
  (messages || []).forEach(item => {
    sourceObj[item.key] = item.targetDefaultMessage;
  });
  if (!fs.existsSync(filePath)) {
    fs.mkdirSync(filePath);
  }
  fs.writeFileSync(pathTool.join(filePath, '/zh_CN.json'), JSON.stringify(sourceObj, null, 2));
}

module.exports = {
  scan,
  writeFile,
};
